﻿Imports System.Collections.ObjectModel
Imports ThinkGeo.MapSuite.Core
Imports ThinkGeo.MapSuite.WebEdition

Partial Class _Default
    Inherits System.Web.UI.Page

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As EventArgs) Handles Me.Load

        If Not Page.IsPostBack Then
            Map1.CurrentExtent = New RectangleShape(-125, 72, 50, -46)
            Map1.MapUnit = GeographyUnit.DecimalDegree

            Dim worldMapKitOverlay As New WorldMapKitWmsWebOverlay()
            Map1.CustomOverlays.Add(worldMapKitOverlay)

            'this is the data source which you want to filter
            Dim pointLayer As New InMemoryFeatureLayer()
            pointLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = New PointStyle(PointSymbolType.Circle, New GeoSolidBrush(GeoColor.FromArgb(150, GeoColor.StandardColors.White)), New GeoPen(New GeoSolidBrush(GeoColor.FromArgb(150, GeoColor.StandardColors.Black)), 1), 15)
            pointLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20

            Dim pointOverlay As New LayerOverlay("PointOverlay")
            pointOverlay.IsBaseOverlay = False
            pointOverlay.TileType = TileType.SingleTile
            pointOverlay.Layers.Add("PointLayer", pointLayer)
            Map1.CustomOverlays.Add(pointOverlay)

            'add several random points into the data source
            Dim random As New Random()
            For index As Integer = 0 To 500
                Dim x As Double = random.Next(-180, 180)
                Dim y As Double = random.Next(-90, 90)
                pointLayer.InternalFeatures.Add(New Feature(New PointShape(x, y)))
            Next

            'I'm not sure where you want to insert the feature or markers, so here I implement two ways for you.
            Dim selectedPointLayer As New InMemoryFeatureLayer()
            selectedPointLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = New PointStyle(PointSymbolType.Circle, New GeoSolidBrush(GeoColor.FromArgb(150, GeoColor.StandardColors.Red)), New GeoPen(New GeoSolidBrush(GeoColor.FromArgb(150, GeoColor.StandardColors.Blue)), 1), 15)
            selectedPointLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20
            pointOverlay.Layers.Add("SelectedPointLayer", selectedPointLayer)

            Dim selectedMarkerOverlay As New InMemoryMarkerOverlay("SelectedMarkerOverlay")
            selectedMarkerOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.WebImage.ImageOffsetX = -10.5F
            selectedMarkerOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.WebImage.ImageOffsetY = -25.0F
            selectedMarkerOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.WebImage.ImageWidth = 21
            selectedMarkerOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.WebImage.ImageHeight = 25
            selectedMarkerOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20
            Map1.CustomOverlays.Add(selectedMarkerOverlay)

            Map1.EditOverlay.TrackMode = TrackMode.Rectangle
        End If

    End Sub

    Protected Sub Map1_FinishedTrackShape(ByVal sender As Object, ByVal e As EventArgs) Handles Map1.TrackShapeFinished
        Dim pointOverlay As LayerOverlay = Map1.CustomOverlays("PointOverlay")
        Dim selectedMarkerOverlay As InMemoryMarkerOverlay = Map1.CustomOverlays("SelectedMarkerOverlay")

        Dim pointLayer As InMemoryFeatureLayer = DirectCast(pointOverlay.Layers("PointLayer"), InMemoryFeatureLayer)
        Dim selectedPointLayer As InMemoryFeatureLayer = DirectCast(pointOverlay.Layers("SelectedPointLayer"), InMemoryFeatureLayer)
        selectedPointLayer.InternalFeatures.Clear()
        selectedMarkerOverlay.Features.Clear()

        If Map1.EditOverlay.Features.Count <> 0 Then
            Dim box As RectangleShape = Map1.EditOverlay.Features(Map1.EditOverlay.Features.Count - 1).GetShape().GetBoundingBox()
            pointLayer.Open()
            Dim selectedFeatures As Collection(Of Feature) = pointLayer.QueryTools.GetFeaturesInsideBoundingBox(box, ReturningColumnsType.NoColumns)
            pointLayer.Close()

            For Each feature As Feature In selectedFeatures
                selectedPointLayer.InternalFeatures.Add(feature.CloneDeep(ReturningColumnsType.NoColumns))
                selectedMarkerOverlay.Features.Add(feature.CloneDeep(ReturningColumnsType.NoColumns))
            Next
        End If
        pointOverlay.Redraw()
        Map1.EditOverlay.Features.Clear()
    End Sub

End Class
